@@ -105,7 +105,7 @@ def trigger(outdir, ncdata, mapd, maxdist=0):
                                            coords=wlhin.coords,
                                            dims=wlhin.dims,
                                            attrs={'units':'m'})
-        flag = np.any(wlhin.values > wlhin['thr1'].values, axis=1)
+        flag = np.logical_and(np.any(wlhin.values > wlhin['thr1'].values, axis=1),(mapdreg['dist'] <= maxdist).values)
         for idx in np.where(flag)[0]:
             ffirst[idx] = wlhin.isel(stations=idx).values[np.where((wlhin.values > wlhin['thr1'].values)[idx,:])[0][0]]
     if 'thr2' in mapdreg.columns:
